@@ -15,6 +15,7 @@ import copy
 import math
 
 import numpy as np
+# pylint: disable=no-member
 import scipy.io
 
 
@@ -353,7 +354,9 @@ def __get_out_file(in_file, out_dir):
     if out_dir == '':
         out_dir = os.path.dirname(in_file)
     file_no_ext = os.path.splitext(in_file)[0].split(os.sep)[-1]
-    out_file = '{}/{}'.format(out_dir, file_no_ext)
+    if out_dir == '':
+        out_dir = '.'
+    out_file = '/'.join([out_dir, file_no_ext])
     return file_no_ext, out_dir, out_file
 
 
@@ -435,7 +438,7 @@ def import_del(in_file, force=False, deli='\t', dec_mark='.', out_ext='npz',
     return out_file, import_status, out_dict
 
 
-def __gen_acc_time(step_time, outformat='npz'):
+def __gen_acc_time(step_time, steps, outformat='npz'):
     """
 
     For files produced by PCS Instrument test rigs, generate a continuous time
@@ -449,6 +452,23 @@ def __gen_acc_time(step_time, outformat='npz'):
     # get index of first data point of each step
     step_start = np.append([0], [step_end[0:-1] + 1])
 
+    # add empty steps for mapper steps
+    step_start_with_other = []
+    step_end_with_other = []
+    idx = 0
+    for step_type in steps:
+        if step_type == 'data':
+            step_start_with_other.append(step_start[idx])
+            step_end_with_other.append(step_end[idx])
+            idx += 1
+        elif step_type == 'other':
+            if step_start_with_other:
+                step_start_with_other.append(step_end_with_other[-1])
+                step_end_with_other.append(step_end_with_other[-1])
+            else:
+                step_start_with_other.append(0)
+                step_end_with_other.append(0)
+
     # loop over steps and create continuous time axis
     time_accumulated_s = copy.copy(step_time)
     offset = 0
@@ -460,12 +480,12 @@ def __gen_acc_time(step_time, outformat='npz'):
     # save data to dictionary
     if outformat == 'mat':
         sub_dict = {'time_accumulated_s': time_accumulated_s,
-                    'step_start': step_start + 1,
-                    'step_end': step_end + 1}
+                    'step_start': step_start_with_other + 1,
+                    'step_end': step_end_with_other + 1}
     else:
         sub_dict = {'time_accumulated_s': time_accumulated_s,
-                    'step_start': step_start,
-                    'step_end': step_end}
+                    'step_start': step_start_with_other,
+                    'step_end': step_end_with_other}
     return sub_dict
 
 
@@ -510,6 +530,36 @@ def __post_process_image_data(out_dict):
     return img_dat
 
 
+def __get_pcs_steps(in_file):
+    """
+
+    Get a list indicating the type of step for each step in a PCS data file.
+
+    Parameters
+    ----------
+    in_file: str
+        Path to PCS file
+
+    Returns
+    -------
+    steps: list
+        A list of step types. for numeric data, the step type is 'data', for
+        other step types 'other'
+
+    """
+    steps = []
+    with open(in_file) as dat_file:
+        for line in dat_file:
+            if line.startswith('Step ') and ' started at ' in line:
+                steps.append('data')
+            if line.startswith('Step type	MAPPER	') or \
+                line.startswith('Step type	ZERO_CHECK	') or \
+                line.startswith('Step type	FILM_ZERO	') or \
+                line.startswith('Step type	HEATING	'):
+                steps[-1] = 'other'
+    return steps
+
+
 def import_pcs(in_file, force=False, out_ext='npz', out_dir=''):
     """
 
@@ -554,20 +604,26 @@ def import_pcs(in_file, force=False, out_ext='npz', out_dir=''):
         __import_file(in_file, out_file_no_ext, out_ext, force=force, deli='\t',
                       dec_mark='.', pad=8)
 
+    steps = __get_pcs_steps(in_file)
+
     if import_status is True:
         out_dict = __write_to_out_dict(num_dat, col_heads, pcs=True)
 
-        if 'step_time_s' in out_dict:
-            t_dict = \
-                __gen_acc_time(out_dict['step_time_s'].astype(float), out_ext)
-            out_dict = {**out_dict, **t_dict}
-
         try:
+            if 'step_time_s' in out_dict:
+                t_dict = \
+                    __gen_acc_time(out_dict['step_time_s'].astype(float), steps,
+                                   out_ext)
+                out_dict = {**out_dict, **t_dict}
             out_dict = {**out_dict, **__post_process_image_data(out_dict)}
         except KeyError:
             pass
+        except IndexError:
+            out_dict = None
+            import_status = False
 
-        out_file = __save_out_file(out_file_no_ext, out_dict, out_ext)
+        if import_status:
+            out_file = __save_out_file(out_file_no_ext, out_dict, out_ext)
 
     return out_file, import_status, out_dict
 
